package main

import (
	"fmt"
	"net/http"
	"sirlab.de/go/knyt/app"
	"sirlab.de/go/knyt/engine"
	"sirlab.de/go/knyt/handler"
	"sirlab.de/go/knyt/user"
	"sirlab.de/go/knyt/users"
)

func main() {
	appConfig := app.NewAppConfig()
	App := app.NewApp(appConfig)
	App.Mux = handler.NewAuthMux()
	App.Eng = engine.NewEngine()
	http.Handle("/", App.Mux)

	usrs := users.NewUsers()
	u1 := user.NewUser("123", "Volkmar", user.ROLE_PLAYER)
	u2 := user.NewUser("123", "Annabell", user.ROLE_GAMEMASTER)
	usrs.AddUser(u1)
	usrs.AddUser(u2)

	App.Mux.PublicHandleFunc("/__intern__/exit", handler.Exit)

	// default handler
	fsHandler := http.FileServer(http.Dir("../client/dist/"))
	App.Mux.PublicHandle("/", fsHandler)

	App.Mux.PublicHandleFunc("/api/sync", App.Eng.GetHttpHandler())
	go App.Eng.Run()

	// start listening
	fmt.Println("http://localhost:32039")
	http.ListenAndServe(":32039", nil)
}
